The PyCFRL Team
===============

Maintainer
---------------

- Jianhan Zhang [jianhanz@umich.edu], *Department of Statistics, University of Michigan, USA*

Contributors
---------------

- Jitao Wang [jitwang@umich.edu], *Department of Biostatistics, University of Michigan, USA*

- Chengchun Shi, *Department of Statistics, London School of Economics, UK*

- John D. Piette, *Department of Health Behavior and Health Equity, School of Public Health, 
  University of Michigan, USA*

- Donglin Zeng, *Department of Biostatistics, University of Michigan, USA*

- Zhenke Wu [zhenkewu@umich.edu], *Department of Biostatistics, University of Michigan, USA*